@@ -1,4 +1,17 @@
-from typing import Any, Dict, List, Optional
+# Copyright Amazon.com Inc. or its affiliates. All Rights Reserved.
+#
+# Licensed under the Apache License, Version 2.0 (the "License"). You
+# may not use this file except in compliance with the License. A copy of
+# the License is located at
+#
+#     http://aws.amazon.com/apache2.0/
+#
+# or in the "license" file accompanying this file. This file is
+# distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF
+# ANY KIND, either express or implied. See the License for the specific
+# language governing permissions and limitations under the License
+
+from typing import Any, Optional
 
 from pydantic.v1 import BaseModel
 
@@ -24,5 +37,5 @@ class Frame(BaseModel):
     centerFrequency: Optional[float]
     phase: float
     associatedGate: Optional[str]
-    qubitMappings: Optional[List[int]]
-    qhpSpecificProperties: Optional[Dict[str, Any]]
+    qubitMappings: Optional[list[int]]
+    qhpSpecificProperties: Optional[dict[str, Any]]
